Index: src/x64/code-stubs-x64.h |
diff --git a/src/x64/code-stubs-x64.h b/src/x64/code-stubs-x64.h |
index 9d34e8570597a60d067089aa72e04c28a1749041..7d174e58e6dae4ac3f3d6eab6272ee311c52a32b 100644 |
--- a/src/x64/code-stubs-x64.h |
+++ b/src/x64/code-stubs-x64.h |
@@ -23,26 +23,21 @@ class StringHelper : public AllStatic { |
Register count, |
String::Encoding encoding); |
- // Compares two flat ASCII strings and returns result in rax. |
- static void GenerateCompareFlatAsciiStrings( |
+ // Compares two flat one-byte strings and returns result in rax. |
+ static void GenerateCompareFlatOneByteStrings( |
MacroAssembler* masm, Register left, Register right, Register scratch1, |
Register scratch2, Register scratch3, Register scratch4); |
- // Compares two flat ASCII strings for equality and returns result in rax. |
- static void GenerateFlatAsciiStringEquals(MacroAssembler* masm, |
- Register left, |
- Register right, |
- Register scratch1, |
- Register scratch2); |
+ // Compares two flat one-byte strings for equality and returns result in rax. |
+ static void GenerateFlatOneByteStringEquals(MacroAssembler* masm, |
+ Register left, Register right, |
+ Register scratch1, |
+ Register scratch2); |
private: |
- static void GenerateAsciiCharsCompareLoop( |
- MacroAssembler* masm, |
- Register left, |
- Register right, |
- Register length, |
- Register scratch, |
- Label* chars_not_equal, |
+ static void GenerateOneByteCharsCompareLoop( |
+ MacroAssembler* masm, Register left, Register right, Register length, |
+ Register scratch, Label* chars_not_equal, |
Label::Distance near_jump = Label::kFar); |
DISALLOW_IMPLICIT_CONSTRUCTORS(StringHelper); |